==> kotlin-uikit-3.7.6-pre.15-kotlin-1.6.10.jar: kotlin-js-wrappers-kotlin-uikit-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kotlin-js-wrappers-kotlin-uikit-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kotlin-js-wrappers-kotlin-uikit-js-legacy'.");
    }root['kotlin-js-wrappers-kotlin-uikit-js-legacy'] = factory(typeof this['kotlin-js-wrappers-kotlin-uikit-js-legacy'] === 'undefined' ? {} : this['kotlin-js-wrappers-kotlin-uikit-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Kind_OBJECT = Kotlin.Kind.OBJECT;
  function AccordionEvents() {
    AccordionEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  AccordionEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'AccordionEvents',
    interfaces: []
  };
  var AccordionEvents_instance = null;
  function AccordionEvents_getInstance() {
    if (AccordionEvents_instance === null) {
      new AccordionEvents();
    }return AccordionEvents_instance;
  }
  function AlertEvents() {
    AlertEvents_instance = this;
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
  }
  AlertEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'AlertEvents',
    interfaces: []
  };
  var AlertEvents_instance = null;
  function AlertEvents_getInstance() {
    if (AlertEvents_instance === null) {
      new AlertEvents();
    }return AlertEvents_instance;
  }
  function DropEvents() {
    DropEvents_instance = this;
    this.toggle = 'toggle';
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
    this.stack = 'stack';
  }
  DropEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'DropEvents',
    interfaces: []
  };
  var DropEvents_instance = null;
  function DropEvents_getInstance() {
    if (DropEvents_instance === null) {
      new DropEvents();
    }return DropEvents_instance;
  }
  function DropdownEvents() {
    DropdownEvents_instance = this;
    this.toggle = 'toggle';
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
    this.stack = 'stack';
  }
  DropdownEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'DropdownEvents',
    interfaces: []
  };
  var DropdownEvents_instance = null;
  function DropdownEvents_getInstance() {
    if (DropdownEvents_instance === null) {
      new DropdownEvents();
    }return DropdownEvents_instance;
  }
  function FilterEvents() {
    FilterEvents_instance = this;
    this.beforeFilter = 'beforeFilter';
    this.afterFilter = 'afterFilter';
  }
  FilterEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'FilterEvents',
    interfaces: []
  };
  var FilterEvents_instance = null;
  function FilterEvents_getInstance() {
    if (FilterEvents_instance === null) {
      new FilterEvents();
    }return FilterEvents_instance;
  }
  function LightboxPanelEvents() {
    LightboxPanelEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
    this.itemLoad = 'itemlaod';
    this.beforeItemShow = 'beforeitemshow';
    this.itemShow = 'itemshow';
    this.itemShown = 'itemshown';
    this.beforeItemHide = 'beforeitemhide';
    this.itemHide = 'itemhide';
    this.itemHidden = 'itemhidden';
  }
  LightboxPanelEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'LightboxPanelEvents',
    interfaces: []
  };
  var LightboxPanelEvents_instance = null;
  function LightboxPanelEvents_getInstance() {
    if (LightboxPanelEvents_instance === null) {
      new LightboxPanelEvents();
    }return LightboxPanelEvents_instance;
  }
  function ModalEvents() {
    ModalEvents_instance = this;
    this.beforeShow = 'beforeShow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforeHide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  ModalEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ModalEvents',
    interfaces: []
  };
  var ModalEvents_instance = null;
  function ModalEvents_getInstance() {
    if (ModalEvents_instance === null) {
      new ModalEvents();
    }return ModalEvents_instance;
  }
  function NavbarEvents() {
    NavbarEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  NavbarEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'NavbarEvents',
    interfaces: []
  };
  var NavbarEvents_instance = null;
  function NavbarEvents_getInstance() {
    if (NavbarEvents_instance === null) {
      new NavbarEvents();
    }return NavbarEvents_instance;
  }
  function NotificationEvents() {
    NotificationEvents_instance = this;
    this.close = 'close';
  }
  NotificationEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'NotificationEvents',
    interfaces: []
  };
  var NotificationEvents_instance = null;
  function NotificationEvents_getInstance() {
    if (NotificationEvents_instance === null) {
      new NotificationEvents();
    }return NotificationEvents_instance;
  }
  function OffcanvasEvents() {
    OffcanvasEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  OffcanvasEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'OffcanvasEvents',
    interfaces: []
  };
  var OffcanvasEvents_instance = null;
  function OffcanvasEvents_getInstance() {
    if (OffcanvasEvents_instance === null) {
      new OffcanvasEvents();
    }return OffcanvasEvents_instance;
  }
  function ScrollEvents() {
    ScrollEvents_instance = this;
    this.beforeScroll = 'beforescroll';
    this.scrolled = 'scrolled';
  }
  ScrollEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ScrollEvents',
    interfaces: []
  };
  var ScrollEvents_instance = null;
  function ScrollEvents_getInstance() {
    if (ScrollEvents_instance === null) {
      new ScrollEvents();
    }return ScrollEvents_instance;
  }
  function ScrollspyEvents() {
    ScrollspyEvents_instance = this;
    this.inView = 'inview';
    this.outView = 'outview';
  }
  ScrollspyEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ScrollspyEvents',
    interfaces: []
  };
  var ScrollspyEvents_instance = null;
  function ScrollspyEvents_getInstance() {
    if (ScrollspyEvents_instance === null) {
      new ScrollspyEvents();
    }return ScrollspyEvents_instance;
  }
  function ScrollspyNavEvents() {
    ScrollspyNavEvents_instance = this;
    this.active = 'active';
  }
  ScrollspyNavEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ScrollspyNavEvents',
    interfaces: []
  };
  var ScrollspyNavEvents_instance = null;
  function ScrollspyNavEvents_getInstance() {
    if (ScrollspyNavEvents_instance === null) {
      new ScrollspyNavEvents();
    }return ScrollspyNavEvents_instance;
  }
  function SliderEvents() {
    SliderEvents_instance = this;
    this.beforeItemShow = 'beforeitemshow';
    this.itemShow = 'itemshow';
    this.itemShown = 'itemshown';
    this.beforeItemHide = 'beforeitemhide';
    this.itemHide = 'itemhide';
    this.itemHidden = 'itemhidden';
  }
  SliderEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SliderEvents',
    interfaces: []
  };
  var SliderEvents_instance = null;
  function SliderEvents_getInstance() {
    if (SliderEvents_instance === null) {
      new SliderEvents();
    }return SliderEvents_instance;
  }
  function SlideshowEvents() {
    SlideshowEvents_instance = this;
    this.beforeItemShow = 'beforeitemshow';
    this.itemShow = 'itemshow';
    this.itemShown = 'itemshown';
    this.beforeItemHide = 'beforeitemhide';
    this.itemHide = 'itemhide';
    this.itemHidden = 'itemhidden';
  }
  SlideshowEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SlideshowEvents',
    interfaces: []
  };
  var SlideshowEvents_instance = null;
  function SlideshowEvents_getInstance() {
    if (SlideshowEvents_instance === null) {
      new SlideshowEvents();
    }return SlideshowEvents_instance;
  }
  function SortableEvents() {
    SortableEvents_instance = this;
    this.start = 'start';
    this.stop = 'stop';
    this.moved = 'moved';
    this.added = 'added';
    this.removed = 'removed';
  }
  SortableEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SortableEvents',
    interfaces: []
  };
  var SortableEvents_instance = null;
  function SortableEvents_getInstance() {
    if (SortableEvents_instance === null) {
      new SortableEvents();
    }return SortableEvents_instance;
  }
  function StickyEvents() {
    StickyEvents_instance = this;
    this.active = 'active';
    this.inactive = 'inactive';
  }
  StickyEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'StickyEvents',
    interfaces: []
  };
  var StickyEvents_instance = null;
  function StickyEvents_getInstance() {
    if (StickyEvents_instance === null) {
      new StickyEvents();
    }return StickyEvents_instance;
  }
  function SwitcherEvents() {
    SwitcherEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  SwitcherEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SwitcherEvents',
    interfaces: []
  };
  var SwitcherEvents_instance = null;
  function SwitcherEvents_getInstance() {
    if (SwitcherEvents_instance === null) {
      new SwitcherEvents();
    }return SwitcherEvents_instance;
  }
  function TabEvents() {
    TabEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  TabEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'TabEvents',
    interfaces: []
  };
  var TabEvents_instance = null;
  function TabEvents_getInstance() {
    if (TabEvents_instance === null) {
      new TabEvents();
    }return TabEvents_instance;
  }
  function ToggleEvents() {
    ToggleEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  ToggleEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ToggleEvents',
    interfaces: []
  };
  var ToggleEvents_instance = null;
  function ToggleEvents_getInstance() {
    if (ToggleEvents_instance === null) {
      new ToggleEvents();
    }return ToggleEvents_instance;
  }
  function TooltipEvents() {
    TooltipEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  TooltipEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'TooltipEvents',
    interfaces: []
  };
  var TooltipEvents_instance = null;
  function TooltipEvents_getInstance() {
    if (TooltipEvents_instance === null) {
      new TooltipEvents();
    }return TooltipEvents_instance;
  }
  function UploadEvents() {
    UploadEvents_instance = this;
    this.upload = 'upload';
  }
  UploadEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'UploadEvents',
    interfaces: []
  };
  var UploadEvents_instance = null;
  function UploadEvents_getInstance() {
    if (UploadEvents_instance === null) {
      new UploadEvents();
    }return UploadEvents_instance;
  }
  var package$uikit = _.uikit || (_.uikit = {});
  var package$components = package$uikit.components || (package$uikit.components = {});
  Object.defineProperty(package$components, 'AccordionEvents', {
    get: AccordionEvents_getInstance
  });
  Object.defineProperty(package$components, 'AlertEvents', {
    get: AlertEvents_getInstance
  });
  Object.defineProperty(package$components, 'DropEvents', {
    get: DropEvents_getInstance
  });
  Object.defineProperty(package$components, 'DropdownEvents', {
    get: DropdownEvents_getInstance
  });
  Object.defineProperty(package$components, 'FilterEvents', {
    get: FilterEvents_getInstance
  });
  Object.defineProperty(package$components, 'LightboxPanelEvents', {
    get: LightboxPanelEvents_getInstance
  });
  Object.defineProperty(package$components, 'ModalEvents', {
    get: ModalEvents_getInstance
  });
  Object.defineProperty(package$components, 'NavbarEvents', {
    get: NavbarEvents_getInstance
  });
  Object.defineProperty(package$components, 'NotificationEvents', {
    get: NotificationEvents_getInstance
  });
  Object.defineProperty(package$components, 'OffcanvasEvents', {
    get: OffcanvasEvents_getInstance
  });
  Object.defineProperty(package$components, 'ScrollEvents', {
    get: ScrollEvents_getInstance
  });
  Object.defineProperty(package$components, 'ScrollspyEvents', {
    get: ScrollspyEvents_getInstance
  });
  Object.defineProperty(package$components, 'ScrollspyNavEvents', {
    get: ScrollspyNavEvents_getInstance
  });
  Object.defineProperty(package$components, 'SliderEvents', {
    get: SliderEvents_getInstance
  });
  Object.defineProperty(package$components, 'SlideshowEvents', {
    get: SlideshowEvents_getInstance
  });
  Object.defineProperty(package$components, 'SortableEvents', {
    get: SortableEvents_getInstance
  });
  Object.defineProperty(package$components, 'StickyEvents', {
    get: StickyEvents_getInstance
  });
  Object.defineProperty(package$components, 'SwitcherEvents', {
    get: SwitcherEvents_getInstance
  });
  Object.defineProperty(package$components, 'TabEvents', {
    get: TabEvents_getInstance
  });
  Object.defineProperty(package$components, 'ToggleEvents', {
    get: ToggleEvents_getInstance
  });
  Object.defineProperty(package$components, 'TooltipEvents', {
    get: TooltipEvents_getInstance
  });
  Object.defineProperty(package$components, 'UploadEvents', {
    get: UploadEvents_getInstance
  });
  Kotlin.defineModule('kotlin-js-wrappers-kotlin-uikit-js-legacy', _);
  return _;
}));

==> kotlin-uikit-3.13.7-pre.18-kotlin-1.6.20.jar: kotlin-js-wrappers-kotlin-uikit-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kotlin-js-wrappers-kotlin-uikit-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kotlin-js-wrappers-kotlin-uikit-js-legacy'.");
    }
    root['kotlin-js-wrappers-kotlin-uikit-js-legacy'] = factory(typeof this['kotlin-js-wrappers-kotlin-uikit-js-legacy'] === 'undefined' ? {} : this['kotlin-js-wrappers-kotlin-uikit-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Kind_OBJECT = Kotlin.Kind.OBJECT;
  function AccordionEvents() {
    AccordionEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  AccordionEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'AccordionEvents',
    interfaces: []
  };
  var AccordionEvents_instance = null;
  function AccordionEvents_getInstance() {
    if (AccordionEvents_instance === null) {
      new AccordionEvents();
    }
    return AccordionEvents_instance;
  }
  function AlertEvents() {
    AlertEvents_instance = this;
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
  }
  AlertEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'AlertEvents',
    interfaces: []
  };
  var AlertEvents_instance = null;
  function AlertEvents_getInstance() {
    if (AlertEvents_instance === null) {
      new AlertEvents();
    }
    return AlertEvents_instance;
  }
  function DropEvents() {
    DropEvents_instance = this;
    this.toggle = 'toggle';
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
    this.stack = 'stack';
  }
  DropEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'DropEvents',
    interfaces: []
  };
  var DropEvents_instance = null;
  function DropEvents_getInstance() {
    if (DropEvents_instance === null) {
      new DropEvents();
    }
    return DropEvents_instance;
  }
  function DropdownEvents() {
    DropdownEvents_instance = this;
    this.toggle = 'toggle';
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
    this.stack = 'stack';
  }
  DropdownEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'DropdownEvents',
    interfaces: []
  };
  var DropdownEvents_instance = null;
  function DropdownEvents_getInstance() {
    if (DropdownEvents_instance === null) {
      new DropdownEvents();
    }
    return DropdownEvents_instance;
  }
  function FilterEvents() {
    FilterEvents_instance = this;
    this.beforeFilter = 'beforeFilter';
    this.afterFilter = 'afterFilter';
  }
  FilterEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'FilterEvents',
    interfaces: []
  };
  var FilterEvents_instance = null;
  function FilterEvents_getInstance() {
    if (FilterEvents_instance === null) {
      new FilterEvents();
    }
    return FilterEvents_instance;
  }
  function LightboxPanelEvents() {
    LightboxPanelEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
    this.itemLoad = 'itemlaod';
    this.beforeItemShow = 'beforeitemshow';
    this.itemShow = 'itemshow';
    this.itemShown = 'itemshown';
    this.beforeItemHide = 'beforeitemhide';
    this.itemHide = 'itemhide';
    this.itemHidden = 'itemhidden';
  }
  LightboxPanelEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'LightboxPanelEvents',
    interfaces: []
  };
  var LightboxPanelEvents_instance = null;
  function LightboxPanelEvents_getInstance() {
    if (LightboxPanelEvents_instance === null) {
      new LightboxPanelEvents();
    }
    return LightboxPanelEvents_instance;
  }
  function ModalEvents() {
    ModalEvents_instance = this;
    this.beforeShow = 'beforeShow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforeHide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  ModalEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ModalEvents',
    interfaces: []
  };
  var ModalEvents_instance = null;
  function ModalEvents_getInstance() {
    if (ModalEvents_instance === null) {
      new ModalEvents();
    }
    return ModalEvents_instance;
  }
  function NavbarEvents() {
    NavbarEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  NavbarEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'NavbarEvents',
    interfaces: []
  };
  var NavbarEvents_instance = null;
  function NavbarEvents_getInstance() {
    if (NavbarEvents_instance === null) {
      new NavbarEvents();
    }
    return NavbarEvents_instance;
  }
  function NotificationEvents() {
    NotificationEvents_instance = this;
    this.close = 'close';
  }
  NotificationEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'NotificationEvents',
    interfaces: []
  };
  var NotificationEvents_instance = null;
  function NotificationEvents_getInstance() {
    if (NotificationEvents_instance === null) {
      new NotificationEvents();
    }
    return NotificationEvents_instance;
  }
  function OffCanvasEvents() {
    OffCanvasEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  OffCanvasEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'OffCanvasEvents',
    interfaces: []
  };
  var OffCanvasEvents_instance = null;
  function OffCanvasEvents_getInstance() {
    if (OffCanvasEvents_instance === null) {
      new OffCanvasEvents();
    }
    return OffCanvasEvents_instance;
  }
  function ScrollEvents() {
    ScrollEvents_instance = this;
    this.beforeScroll = 'beforescroll';
    this.scrolled = 'scrolled';
  }
  ScrollEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ScrollEvents',
    interfaces: []
  };
  var ScrollEvents_instance = null;
  function ScrollEvents_getInstance() {
    if (ScrollEvents_instance === null) {
      new ScrollEvents();
    }
    return ScrollEvents_instance;
  }
  function ScrollspyEvents() {
    ScrollspyEvents_instance = this;
    this.inView = 'inview';
    this.outView = 'outview';
  }
  ScrollspyEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ScrollspyEvents',
    interfaces: []
  };
  var ScrollspyEvents_instance = null;
  function ScrollspyEvents_getInstance() {
    if (ScrollspyEvents_instance === null) {
      new ScrollspyEvents();
    }
    return ScrollspyEvents_instance;
  }
  function ScrollspyNavEvents() {
    ScrollspyNavEvents_instance = this;
    this.active = 'active';
  }
  ScrollspyNavEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ScrollspyNavEvents',
    interfaces: []
  };
  var ScrollspyNavEvents_instance = null;
  function ScrollspyNavEvents_getInstance() {
    if (ScrollspyNavEvents_instance === null) {
      new ScrollspyNavEvents();
    }
    return ScrollspyNavEvents_instance;
  }
  function SliderEvents() {
    SliderEvents_instance = this;
    this.beforeItemShow = 'beforeitemshow';
    this.itemShow = 'itemshow';
    this.itemShown = 'itemshown';
    this.beforeItemHide = 'beforeitemhide';
    this.itemHide = 'itemhide';
    this.itemHidden = 'itemhidden';
  }
  SliderEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SliderEvents',
    interfaces: []
  };
  var SliderEvents_instance = null;
  function SliderEvents_getInstance() {
    if (SliderEvents_instance === null) {
      new SliderEvents();
    }
    return SliderEvents_instance;
  }
  function SlideshowEvents() {
    SlideshowEvents_instance = this;
    this.beforeItemShow = 'beforeitemshow';
    this.itemShow = 'itemshow';
    this.itemShown = 'itemshown';
    this.beforeItemHide = 'beforeitemhide';
    this.itemHide = 'itemhide';
    this.itemHidden = 'itemhidden';
  }
  SlideshowEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SlideshowEvents',
    interfaces: []
  };
  var SlideshowEvents_instance = null;
  function SlideshowEvents_getInstance() {
    if (SlideshowEvents_instance === null) {
      new SlideshowEvents();
    }
    return SlideshowEvents_instance;
  }
  function SortableEvents() {
    SortableEvents_instance = this;
    this.start = 'start';
    this.stop = 'stop';
    this.moved = 'moved';
    this.added = 'added';
    this.removed = 'removed';
  }
  SortableEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SortableEvents',
    interfaces: []
  };
  var SortableEvents_instance = null;
  function SortableEvents_getInstance() {
    if (SortableEvents_instance === null) {
      new SortableEvents();
    }
    return SortableEvents_instance;
  }
  function StickyEvents() {
    StickyEvents_instance = this;
    this.active = 'active';
    this.inactive = 'inactive';
  }
  StickyEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'StickyEvents',
    interfaces: []
  };
  var StickyEvents_instance = null;
  function StickyEvents_getInstance() {
    if (StickyEvents_instance === null) {
      new StickyEvents();
    }
    return StickyEvents_instance;
  }
  function SwitcherEvents() {
    SwitcherEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  SwitcherEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'SwitcherEvents',
    interfaces: []
  };
  var SwitcherEvents_instance = null;
  function SwitcherEvents_getInstance() {
    if (SwitcherEvents_instance === null) {
      new SwitcherEvents();
    }
    return SwitcherEvents_instance;
  }
  function TabEvents() {
    TabEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  TabEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'TabEvents',
    interfaces: []
  };
  var TabEvents_instance = null;
  function TabEvents_getInstance() {
    if (TabEvents_instance === null) {
      new TabEvents();
    }
    return TabEvents_instance;
  }
  function ToggleEvents() {
    ToggleEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  ToggleEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'ToggleEvents',
    interfaces: []
  };
  var ToggleEvents_instance = null;
  function ToggleEvents_getInstance() {
    if (ToggleEvents_instance === null) {
      new ToggleEvents();
    }
    return ToggleEvents_instance;
  }
  function TooltipEvents() {
    TooltipEvents_instance = this;
    this.beforeShow = 'beforeshow';
    this.show = 'show';
    this.shown = 'shown';
    this.beforeHide = 'beforehide';
    this.hide = 'hide';
    this.hidden = 'hidden';
  }
  TooltipEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'TooltipEvents',
    interfaces: []
  };
  var TooltipEvents_instance = null;
  function TooltipEvents_getInstance() {
    if (TooltipEvents_instance === null) {
      new TooltipEvents();
    }
    return TooltipEvents_instance;
  }
  function UploadEvents() {
    UploadEvents_instance = this;
    this.upload = 'upload';
  }
  UploadEvents.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'UploadEvents',
    interfaces: []
  };
  var UploadEvents_instance = null;
  function UploadEvents_getInstance() {
    if (UploadEvents_instance === null) {
      new UploadEvents();
    }
    return UploadEvents_instance;
  }
  var package$uikit = _.uikit || (_.uikit = {});
  var package$components = package$uikit.components || (package$uikit.components = {});
  Object.defineProperty(package$components, 'AccordionEvents', {
    get: AccordionEvents_getInstance
  });
  Object.defineProperty(package$components, 'AlertEvents', {
    get: AlertEvents_getInstance
  });
  Object.defineProperty(package$components, 'DropEvents', {
    get: DropEvents_getInstance
  });
  Object.defineProperty(package$components, 'DropdownEvents', {
    get: DropdownEvents_getInstance
  });
  Object.defineProperty(package$components, 'FilterEvents', {
    get: FilterEvents_getInstance
  });
  Object.defineProperty(package$components, 'LightboxPanelEvents', {
    get: LightboxPanelEvents_getInstance
  });
  Object.defineProperty(package$components, 'ModalEvents', {
    get: ModalEvents_getInstance
  });
  Object.defineProperty(package$components, 'NavbarEvents', {
    get: NavbarEvents_getInstance
  });
  Object.defineProperty(package$components, 'NotificationEvents', {
    get: NotificationEvents_getInstance
  });
  Object.defineProperty(package$components, 'OffCanvasEvents', {
    get: OffCanvasEvents_getInstance
  });
  Object.defineProperty(package$components, 'ScrollEvents', {
    get: ScrollEvents_getInstance
  });
  Object.defineProperty(package$components, 'ScrollspyEvents', {
    get: ScrollspyEvents_getInstance
  });
  Object.defineProperty(package$components, 'ScrollspyNavEvents', {
    get: ScrollspyNavEvents_getInstance
  });
  Object.defineProperty(package$components, 'SliderEvents', {
    get: SliderEvents_getInstance
  });
  Object.defineProperty(package$components, 'SlideshowEvents', {
    get: SlideshowEvents_getInstance
  });
  Object.defineProperty(package$components, 'SortableEvents', {
    get: SortableEvents_getInstance
  });
  Object.defineProperty(package$components, 'StickyEvents', {
    get: StickyEvents_getInstance
  });
  Object.defineProperty(package$components, 'SwitcherEvents', {
    get: SwitcherEvents_getInstance
  });
  Object.defineProperty(package$components, 'TabEvents', {
    get: TabEvents_getInstance
  });
  Object.defineProperty(package$components, 'ToggleEvents', {
    get: ToggleEvents_getInstance
  });
  Object.defineProperty(package$components, 'TooltipEvents', {
    get: TooltipEvents_getInstance
  });
  Object.defineProperty(package$components, 'UploadEvents', {
    get: UploadEvents_getInstance
  });
  Kotlin.defineModule('kotlin-js-wrappers-kotlin-uikit-js-legacy', _);
  return _;
}));
